@@ -362,10 +362,8 @@ class Testbed:
             self.sp.stdin.write('\n')
             self.sp.stdin.flush()
             self.lastsend = string
-        except:
-            (type, value, dummy) = sys.exc_info()
-            self.bomb('cannot send to testbed: %s' % traceback.
-                      format_exception_only(type, value))
+        except Exception as e:
+            self.bomb('cannot send to testbed: %s' % e)
 
     def expect(self, keyword, nresults):
         line = self.sp.stdout.readline()
@@ -1178,7 +1176,7 @@ fi
 
         # get release name
         script = 'SRCS=$(ls /etc/apt/sources.list /etc/apt/sources.list.d/*.list 2>/dev/null|| true); '
-        script += '''REL=$(sed -rn '/^(deb|deb-src) .*(ubuntu.com|debian.org|ftpmaster|file:\/\/\/tmp\/testarchive)/ { s/^[^ ]+ +(\[.*\] *)?[^ ]* +([^ -]+) +.*$/\\2/p}' $SRCS | head -n1); '''
+        script += '''REL=$(sed -rn '/^(deb|deb-src) .*(ubuntu.com|debian.org|ftpmaster|file:\/\/\/tmp\/testarchive)/ { s/\[.*\] +//; s/^[^ ]+ +[^ ]* +([^ -]+) +.*$/\\1/p }' $SRCS | head -n1); '''
 
         script += 'mkdir -p /etc/apt/preferences.d; '
         script += 'PKGS="%s"; ' % ' '.join(binpkgs)
